@@ -92,8 +92,7 @@ pub fn main(args: Args) -> Fallible<()> {
             let empty = fs::read_dir(&path)?.next().is_none();
             info!("No Git repository found.");
 
-            let dangerous = (path == home::home_dir().unwrap())
-                || (path.is_absolute() && path.ancestors().next().is_none());
+            let dangerous = (path == home::home_dir().unwrap()) || (path.to_str() == Some("/"));
 
             if dangerous && !args.yes {
                 bail!(
